@@ -17,7 +17,7 @@ import (
 	"gitlab.com/gitlab-org/cli/pkg/utils"
 
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 )
 
 type ListOptions struct {
@@ -35,11 +35,12 @@ type ListOptions struct {
 	Group        string
 
 	// issue states
-	State  string
-	Closed bool
-	Merged bool
-	All    bool
-	Draft  bool
+	State    string
+	Closed   bool
+	Merged   bool
+	All      bool
+	Draft    bool
+	NotDraft bool
 
 	// Pagination
 	Page         int
@@ -76,6 +77,8 @@ func NewCmdList(f *cmdutils.Factory, runE func(opts *ListOptions) error) *cobra.
 			glab mr list --label needs-review
 			glab mr list --not-label waiting-maintainer-feedback,subsystem-x
 			glab mr list -M --per-page 10
+			glab mr list --draft
+			glab mr list --not-draft
 		`),
 		Args: cobra.ExactArgs(0),
 		RunE: func(cmd *cobra.Command, args []string) error {
@@ -134,6 +137,7 @@ func NewCmdList(f *cmdutils.Factory, runE func(opts *ListOptions) error) *cobra.
 	mrListCmd.Flags().BoolVarP(&opts.Closed, "closed", "c", false, "Get only closed merge requests.")
 	mrListCmd.Flags().BoolVarP(&opts.Merged, "merged", "M", false, "Get only merged merge requests.")
 	mrListCmd.Flags().BoolVarP(&opts.Draft, "draft", "d", false, "Filter by draft merge requests.")
+	mrListCmd.Flags().BoolVarP(&opts.NotDraft, "not-draft", "", false, "Filter by non-draft merge requests.")
 	mrListCmd.Flags().StringVarP(&opts.OutputFormat, "output", "F", "text", "Format output as: text, json.")
 	mrListCmd.Flags().IntVarP(&opts.Page, "page", "p", 1, "Page number.")
 	mrListCmd.Flags().IntVarP(&opts.PerPage, "per-page", "P", 30, "Number of items to list per page.")
@@ -148,6 +152,7 @@ func NewCmdList(f *cmdutils.Factory, runE func(opts *ListOptions) error) *cobra.
 	_ = mrListCmd.Flags().MarkHidden("mine")
 	_ = mrListCmd.Flags().MarkDeprecated("mine", "use --assignee=@me.")
 	mrListCmd.PersistentFlags().StringP("group", "g", "", "Select a group/subgroup. This option is ignored if a repo argument is set.")
+	mrListCmd.MarkFlagsMutuallyExclusive("draft", "not-draft")
 
 	return mrListCmd
 }
@@ -219,6 +224,10 @@ func listRun(opts *ListOptions) error {
 		l.WIP = gitlab.Ptr("yes")
 		opts.ListType = "search"
 	}
+	if opts.NotDraft {
+		l.WIP = gitlab.Ptr("no")
+		opts.ListType = "search"
+	}
 
 	if opts.Mine {
 		l.Scope = gitlab.Ptr("assigned_to_me")
@@ -249,13 +258,11 @@ func listRun(opts *ListOptions) error {
 	title := utils.NewListTitle(opts.TitleQualifier + " merge request")
 	title.RepoName = repo.FullName()
 
-	if len(assigneeIds) > 0 || len(reviewerIds) > 0 {
-		mergeRequests, err = api.ListMRsWithAssigneesOrReviewers(apiClient, repo.FullName(), l, assigneeIds, reviewerIds)
-	} else if opts.Group != "" {
-		mergeRequests, err = api.ListGroupMRs(apiClient, opts.Group, api.ProjectListMROptionsToGroup(l))
+	if opts.Group != "" {
+		mergeRequests, err = api.ListGroupMRs(apiClient, opts.Group, api.ProjectListMROptionsToGroup(l), api.WithMRAssignees(assigneeIds), api.WithMRReviewers(reviewerIds))
 		title.RepoName = opts.Group
 	} else {
-		mergeRequests, err = api.ListMRs(apiClient, repo.FullName(), l)
+		mergeRequests, err = api.ListMRs(apiClient, repo.FullName(), l, api.WithMRAssignees(assigneeIds), api.WithMRReviewers(reviewerIds))
 	}
 	if err != nil {
 		return err
